pub enum RexProcessorInstruction {
Report {
rex_id: RexId,
updates: Vec<RexUpdate>,
},
}Expand description
Instructions supported by the REX Processor program. Made to report rex updates from validators.
Variants
Report
Report rex updates from validators
Implementations
Sourceimpl RexProcessorInstruction
impl RexProcessorInstruction
Sourcepub fn report(
payer: Pubkey,
rex_id: RexId,
updates: Vec<RexUpdate>,
) -> Instruction
pub fn report( payer: Pubkey, rex_id: RexId, updates: Vec<RexUpdate>, ) -> Instruction
Creates an instruction for rex reporting.
This function creates an instruction that will report an rex update and emit an event that subscribers can listen to.
Arguments
payer- The public key of the payerrex_id- The ID of the rexupdates- A vector of rex updates
Returns
An instruction that stores rex data in a PDA and emits an event. Subscribers can listen to the instance-specific topic to receive notifications when rex reports are stored.
Accounts
[0]- Payer account (signer, writable)[1]- Report PDA account (writable)[2]- Event PDA account (writable)[3]- System program (readonly)