pub struct RexUpdate { /* private fields */ }Expand description
REX update structure
Implementations
Sourceimpl RexUpdate
impl RexUpdate
pub fn new(data: Vec<u8>, validator: AuthorityKeyBytes) -> Self
Sourcepub fn data(&self) -> &[u8] ⓘ
pub fn data(&self) -> &[u8] ⓘ
Returns the REX data as a Base64 encoded string
Returns
The output that resulted from the REX Duty being performed, serialized as bytes with Borsh
Sourcepub fn validator(&self) -> AuthorityKeyBytes
pub fn validator(&self) -> AuthorityKeyBytes
The 96-byte BLS12-381 authority public key of the validator.
Sourcepub fn try_data_as_output(&self) -> Result<RexOutput, RexProcessorError>
pub fn try_data_as_output(&self) -> Result<RexOutput, RexProcessorError>
Sourcepub fn success_payload(&self) -> Option<RexData>
pub fn success_payload(&self) -> Option<RexData>
Returns the RexData payload returned by the rex if the request was a success.
Otherwise, returns None.
Returns
An Option containing the RexData payload if the rex output was a success, or None otherwise.
pub fn get_rex_response_timestamp(&self) -> Option<String>