The REX Processor program interface.
REX Processor Interface
This crate is meant to be used as both entrypoint definition and utility along with the REX Processor program.
It contains a list of instructions that can be sent to the builtin program, along with some given Rust methods to easily generate them.
Modules
- errors
- event
- Events emitted by the REX Processor program.
- instruction
- Instructions for the REX Processor program.
- state
Constants
- ID
- The const program ID.